==> open-cluster-management-operator-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/FailedProvisionConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FailedProvisionConfigFluent<A extends FailedProvisionConfigFluent<A>> extends BaseFluent<A>{
  public FailedProvisionConfigFluent() {
  }
  public FailedProvisionConfigFluent(FailedProvisionConfig instance) {
    instance = (instance != null ? instance : new FailedProvisionConfig());

    if (instance != null) {
      this.withSkipGatherLogs(instance.getSkipGatherLogs());
      this.withSkipGatherLogs(instance.getSkipGatherLogs());
    }
  }
  private Boolean skipGatherLogs;
  public Boolean getSkipGatherLogs() {
    return this.skipGatherLogs;
  }
  public A withSkipGatherLogs(Boolean skipGatherLogs) {
    this.skipGatherLogs=skipGatherLogs; return (A) this;
  }
  public boolean hasSkipGatherLogs() {
    return this.skipGatherLogs != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FailedProvisionConfigFluent that = (FailedProvisionConfigFluent) o;
    if (!java.util.Objects.equals(skipGatherLogs, that.skipGatherLogs)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(skipGatherLogs,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (skipGatherLogs != null) { sb.append("skipGatherLogs:"); sb.append(skipGatherLogs); }
    sb.append("}");
    return sb.toString();
  }
  public A withSkipGatherLogs() {
    return withSkipGatherLogs(true);
  }
  
}

==> open-cluster-management-operator-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/FailedProvisionConfigFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FailedProvisionConfigFluent<A extends FailedProvisionConfigFluent<A>> extends BaseFluent<A>{
  public FailedProvisionConfigFluent() {
  }
  
  public FailedProvisionConfigFluent(FailedProvisionConfig instance) {
    this.copyInstance(instance);
  }
  private Boolean skipGatherLogs;
  
  protected void copyInstance(FailedProvisionConfig instance) {
    instance = (instance != null ? instance : new FailedProvisionConfig());
    if (instance != null) {
          this.withSkipGatherLogs(instance.getSkipGatherLogs());
          this.withSkipGatherLogs(instance.getSkipGatherLogs());
        }
  }
  
  public Boolean getSkipGatherLogs() {
    return this.skipGatherLogs;
  }
  
  public A withSkipGatherLogs(Boolean skipGatherLogs) {
    this.skipGatherLogs = skipGatherLogs;
    return (A) this;
  }
  
  public boolean hasSkipGatherLogs() {
    return this.skipGatherLogs != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FailedProvisionConfigFluent that = (FailedProvisionConfigFluent) o;
    if (!java.util.Objects.equals(skipGatherLogs, that.skipGatherLogs)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(skipGatherLogs,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (skipGatherLogs != null) { sb.append("skipGatherLogs:"); sb.append(skipGatherLogs); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withSkipGatherLogs() {
    return withSkipGatherLogs(true);
  }
  

}
